<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 5.5.10 (2013/03/09)
 * Compatibility : Guppy v4.6.17+
 * Author   : jrme CROUX (djchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */
if (stristr($_SERVER["SCRIPT_NAME"], "editors_functions.php")) {
  header("location:../index.php");
  die();
}

/**
 * Affiche l'diteur dans la partie administration 
 * 
 * @param string  $name    Nom de l'diteur
 * @param string  $width   Largeur de l'diteur (voir fichier de condif)
 * @param string  $height  Hauteur de l'diteur
 * @param string  $content Contenu de l'diteur
 * @param boolean $wysiwyg Editeur wysiwyg (true) ou non (false)
 * @param array   $params  Paramtres optionnels
 * @return string
 */
function display_admin_editor($name, $width, $height, $content, $wysiwyg = TRUE, $params = array())
{
    $path_editors = 'plugins/adm_redacteurs/editors/';
    
    if ($wysiwyg) {
        WYSIWYG_admin_editor($name, $width, $height, $content, $params, $path_editors);
    } else {
        TEXTAREA_admin_editor($name, $width, $height, $content, $params, $path_editors);   
    }
}

// --------------------------------------------------------------------

/**
 * Affiche un diteur WYSIWYG 
 * 
 * @param string $name Nom de l'diteur
 * @param string $width Largeur de l'diteur (voir fichier de condif)
 * @param string $height Hauteur de l'diteur
 * @param string $value Contenu de l'diteur
 * @param 
 * @return string
 */
function WYSIWYG_admin_editor($name, $width, $height, $value, $params = array(), $path_editors = '')
{
    settype($params, 'array');
    
    /**
     * Editeur CKEditor
     */
    if (is_file(CHEMIN.'inc/ckeditor/ckeditor.php'))
    {
        require_once CHEMIN.'inc/ckeditor/ckeditor.php';
        
        $path = 'inc/ckeditor/';
        $toolbarName = empty($params['toolbarName'])? 'Guppy_in' : $params['toolbarName'];
     
        return CKeditor($name, $path, $width, $height, $value, $toolbarName, $path_editors);
    }
    //
    
    /**
     * Editeur FCKEditor
     */
    if (is_file(CHEMIN.'inc/fckeditor/fckeditor.php'))
    {
        require_once CHEMIN.'inc/fckeditor/fckeditor.php';
        
        $path = 'inc/fckeditor/';
        $toolbarName = empty($params['toolbarName'])? 'Guppy_in' : $params['toolbarName'];
        
        return FCKeditor($name, $path, $width, $height, $value, $toolbarName, $path_editors);        
    }
    //
    
    return FALSE;   
}

// --------------------------------------------------------------------

/**
 * Affiche un diteur NON WYSIWYG 
 * 
 * @param string $name Nom de l'diteur
 * @param string $width Largeur de l'diteur (voir fichier de condif)
 * @param string $height Hauteur de l'diteur
 * @param string $value Contenu de l'diteur
 * @return string
 */
function TEXTAREA_admin_editor($name, $width, $height, $value, $params = array(), $path_editors = '')
{    
	global 	$site,$pathDirMinieditor,$serviz,$lng,$lang_minieditor,$titre,$texte,$bordure,
			$typeFONT,$sizeFONT,$baliseHTML,$classCSS,$targetURL,$alignIMG,$baliseBonus,$colorTextTextarea,$colorFondTextarea,
			$colorFondMenu,$colorFondMenuOver,$colorTextTitre,$colorFondTitre,$tagBeginMinieditor,$tagEndMinieditor,
			$colorTextCorp,$colorFondCorp,$styleBordureCorp,$path_minieditortextarea_config,$pathFilesMinieditor,$IEPopupColor,
			$minieditorStyleMenu,$minieditorStyleSelect,$minieditorStyleTextarea,$minieditorStyleSmiley,$minieditorStyleImgSmiley,$minieditorStyleBR,
			$useTagSPAN;

    $pathMinieditor = $path_editors.'minieditortextarea/minieditortextarea.inc';
    
    if (is_file(CHEMIN.$pathMinieditor))
    {
    	static $editor_id = 1;

        $path_minieditortextarea_config = $path_editors.'minieditortextarea/';	
        require_once CHEMIN.$pathMinieditor;

        $formName = empty($params['formName'])? 'adminsend' : $params['formName'];
        $value = ReplaceHTMLEntities($value);
        
        MiniEditorTextarea($editor_id, $formName, $name, $width, $height, $value);
        
        $editor_id++;
    }
    
    return FALSE;   
}

// --------------------------------------------------------------------

/**
 * Affiche l'diteur WYSIWYG CKEditor
 * 
 * @param string $name Nom de l'diteur
 * @param string $path Chemin relatif du rpertoire contenant l'diteur
 * @param string $width Largeur de l'diteur (voir fichier de condif)
 * @param string $height Hauteur de l'diteur
 * @param string $value Contenu de l'diteur
 * @param string $toolbarname Nom de la barre d'outil de l'diteur
 * @param string $pathDirMinieditor Chemin relatif du rpertoire contenant la configuration de l'diteur
 * @return string
 */
function CKeditor($name, $path, $width, $height, $value, $toolbarname, $pathDirMinieditor)
{
	global $site, $lng;

    /**
     * Cration de l'diteur
     */
	$oCKeditor = new CKeditor() ;
	$oCKeditor -> basePath = $site[3].$path;
    //$oCKeditor -> config['width'] = (strpos($_SERVER['HTTP_USER_AGENT'], "WebKit") !== false)? '577px' : $width;   // Correction bug avec Safari et Chrome
    $oCKeditor -> config['width'] = $width; // (dfinie dans le fichier de configruration admin/editors/ckeditor_config/guppy_ckconfig.js)
	$oCKeditor -> config['height'] = $height;
	$oCKeditor -> config['baseHref'] = $site[3];
	$oCKeditor -> config['customConfig'] = $site[3].$pathDirMinieditor.'ckeditor_config/guppy_ckconfig.js';
	$oCKeditor -> config['contentsCss'] = $site[3].$pathDirMinieditor.'ckeditor_config/custom/guppy_contents.css';
	$oCKeditor -> config['language'] = is_file(CHEMIN.'inc/ckeditor/lang/'.$lng.'.js')? $lng : 'en';	
	$oCKeditor -> config['toolbar'] = $toolbarname;
	$oCKeditor -> config['smiley_path'] = $site[3].'img/smileys/';
	$oCKeditor -> config['filebrowserBrowseUrl'] = $site[3].$pathDirMinieditor.'upload/upload.php?lng='.$lng.'&uptype=Link&namerepconfig=ckeditor_config&pathconfig='.$pathDirMinieditor ; //rcupration du rpertoire file, img, photo, pages et flash de guppy
	$oCKeditor -> config['filebrowserImageBrowseUrl'] = $site[3].$pathDirMinieditor.'upload/upload.php?lng='.$lng.'&uptype=Image&namerepconfig=ckeditor_config&pathconfig='.$pathDirMinieditor; //rcupration du rpertoire img et photo de guppy
	$oCKeditor -> config['filebrowserImageBrowseLinkUrl'] = $site[3].$pathDirMinieditor.'upload/upload.php?lng='.$lng.'&uptype=Link&namerepconfig=ckeditor_config&pathconfig='.$pathDirMinieditor ; //rcupration du rpertoire file, img, photo, pages et flash de guppy
	$oCKeditor -> config['filebrowserFlashBrowseUrl'] = $site[3].$pathDirMinieditor.'upload/upload.php?lng='.$lng.'&uptype=Flash&namerepconfig=ckeditor_config&pathconfig='.$pathDirMinieditor; //rcupration du rpertoire flash de guppy
    //
    
    // Affichage de l'diteur
    $oCKeditor -> editor($name, $value);
	//
    
	// Affichage de la barre de smileys pour l'diteur
    echo get_toolbar_guppy_smileys($name);    
}

// --------------------------------------------------------------------

/**
 * Affiche l'diteur FCKEditor
 * 
 * @param string $name Nom de l'diteur FCKEditor
 * @param string $path Chemin relatif du rpertoire contenant l'diteur
 * @param string $width Largeur de l'diteur FCKEditor
 * @param string $height Hauteur de l'diteur FCKEditor
 * @param string $value Contenu de l'diteur FCKEditor
 * @param string $toolbarname Nom de la barre d'outil de l'diteur FCKEditor
 * @param string $pathDirMinieditor Chemin relatif du rpertoire contenant le minieditor 
 * @return string
 */
function FCKeditor($name, $path, $width, $height, $value, $toolbarname, $pathDirMinieditor)
{
	global $site, $lng;

	// Editeur

	$oFCKeditor1 = new FCKeditor($name) ;
	$oFCKeditor1 -> BasePath = $site[3].$path;
	$oFCKeditor1 -> Width	= $width;
	$oFCKeditor1 -> Height = $height;
	$oFCKeditor1 -> Value = $value;
	$oFCKeditor1 -> Config['BaseHref'] = $site[3];
	$oFCKeditor1 -> Config['CustomConfigurationsPath'] = $site[3].$pathDirMinieditor.'fckeditor_config/guppy_fckconfig.js';
	$oFCKeditor1 -> Config['EditorAreaCSS'] = $site[3].$pathDirMinieditor.'fckeditor_config/custom/guppy_fckeditorarea.css';
	$oFCKeditor1 -> Config["AutoDetectLanguage"] = is_file(CHEMIN.'inc/fckeditor/editor/lang/'.$lng.'.js')? false : true;
	$oFCKeditor1 -> Config['DefaultLanguage'] = is_file(CHEMIN.'inc/fckeditor/editor/lang/'.$lng.'.js')? $lng : 'en';	
	$oFCKeditor1 -> Config['StylesXmlPath'] = $site[3].$pathDirMinieditor.'fckeditor_config/custom/guppy_fckstyles.xml';
	$oFCKeditor1 -> Config['TemplatesXmlPath'] = $site[3].$pathDirMinieditor.'fckeditor_config/custom/guppy_fcktemplates.xml';
	$oFCKeditor1 -> Config['SkinPath'] = $site[3].$pathDirMinieditor.'fckeditor_config/custom/skin_guppy/';
	$oFCKeditor1 -> ToolbarSet = $toolbarname;
	$oFCKeditor1 -> Config['SmileyPath'] = $site[3].'img/smileys/';
	$oFCKeditor1 -> Config['ImageBrowserURL'] = $site[3].$pathDirMinieditor.'upload/upload.php?lng='.$lng.'&uptype=Image&namerepconfig=fckeditor_config&pathconfig='.$pathDirMinieditor; //rcupration du rpertoire img et photo de guppy
	$oFCKeditor1 -> Config['LinkBrowserURL'] = $site[3].$pathDirMinieditor.'upload/upload.php?lng='.$lng.'&uptype=Link&namerepconfig=fckeditor_config&pathconfig='.$pathDirMinieditor ; //rcupration du rpertoire file, img, photo, pages et flash de guppy
	$oFCKeditor1 -> Config['FlashBrowserURL'] = $site[3].$pathDirMinieditor.'upload/upload.php?lng='.$lng.'&uptype=Flash&namerepconfig=fckeditor_config&pathconfig='.$pathDirMinieditor; //rcupration du rpertoire flash de guppy

	// Affichage de l'diteur
	echo '<div style="text-align:center;">';    
    $oFCKeditor1 -> Create();
	echo '</div>';
	
	// Affichage de la barre de smileys pour l'diteur
    echo get_toolbar_guppy_smileys($name);    
}

// --------------------------------------------------------------------

/**
 * Dfini le chemin du rpertoire contenant les smileys de guppy
 */
define('PATH_GUPPYSMILEY', 'inc/img/smileys/');	

// --------------------------------------------------------------------

/**
 * Retourne la barre de smileys de guppy pour tre intgrer dans l'diteur
 * 
 * @param string Nom de l'diteur
 * @return string
 */
function get_toolbar_guppy_smileys($name)
{
	$smileyGuppy = array('cool', 'wink', 'biggrin', 'smile', 'frown', 'eek', 'mad', 'confused', 'rolleyes', 'tongue', 'cry');
	
    $html = '<div class="guppy_smileys" style="text-align:center; margin-top:10px;">';
    
	for ($i = 0; $i < count($smileyGuppy); $i++) {
		$smileyPath = CHEMIN.PATH_GUPPYSMILEY.$smileyGuppy[$i].'.gif';
		if (is_file($smileyPath)) { 
			$imgSize = getimagesize($smileyPath);
			$html .= '<img class="icon" src="'.$smileyPath.'" '.$imgSize[3].' alt="'.$smileyGuppy[$i].'" title="'.$smileyGuppy[$i].'" onclick="insert_smiley_in_editor(\''.$name.'\', \''.PATH_GUPPYSMILEY.$smileyGuppy[$i].'.gif\', \''.$smileyGuppy[$i].'\', \''.$imgSize[0].'\', \''.$imgSize[1].'\');" onmouseover="this.className=\'icon_hover\'" onmouseout="this.className=\'icon_out\'" />'."\n";
		}
	}
    
    $html .= '</div>';
    
	return $html;
}

// --------------------------------------------------------------------

/**
 * Insre les fonctions javascripts ncessaires pour les diteurs
 */ 
$headinc .= '<script type="text/javascript" src="'.CHEMIN.'plugins/adm_redacteurs/editors/editors_scripts.js"></script>';

// --------------------------------------------------------------------

/**
 * Transforme un chemin relatif en chemin absolu pour images et liens
 * (fonction obsolte)
 */ 
function PathRelativeAbsolute($chaine) {
	return $chaine;
}

// --------------------------------------------------------------------

/**
 * Transforme un chemin absolu en chemin relatif pour images et liens
 */
function PathAbsoluteRelative($chaine)
{
	global $site;

	$str = $chaine;
	
	$in = array(
				'\\',
				'<p>&nbsp;</p>',
				'<br type="_moz" />',
				'<u>',
				'</u>',
				'style="TEXT-DECORATION: underline"',
				'="'.$site[3]
	);
	$out = array(
				'',
				'<br />',
				'',
				'<span style="text-decoration:underline;">',
				'</span>',
				'style="text-decoration: underline;"',
				'="'
	);

	$str = str_replace($in, $out, $str);
	$str = preg_replace("` src=\"(?:\.\.\/)+`", ' src="', $str);
	$str = preg_replace('`(<br />|&#160;)$`', '', $str);
	
	return $str;
}

// --------------------------------------------------------------------

/**
 * Permet de conserver l'affichage de quelques entits HTML dans le textarea du minieditor
 * 
 * @param $chaine string contient la chaine  traiter
 * @return string chaine traite
 */
function ReplaceHTMLEntities($chaine)
{
	$str = $chaine;
    
	$in = array(
		'&amp;',
		'&',
		'&amp;amp;lt;',
		'&amp;amp;gt;',
		'&amp;amp;nbsp;',
		'&amp;amp;#'
	);

	$out = array(
		'&',
		'&amp;amp;',
		'&amp;lt;',
		'&amp;gt;',
		'&amp;nbsp;',
		'&amp;#'
	);

	return empty($str)? $str : str_replace($in, $out, $str);
}

// --------------------------------------------------------------------
